Documentation
¶
Index ¶
- Variables
- func RegisterAgentServiceServer(s grpc.ServiceRegistrar, srv AgentServiceServer)
- func RegisterCollectorServiceServer(s grpc.ServiceRegistrar, srv CollectorServiceServer)
- type Agent
- func (*Agent) Descriptor() ([]byte, []int)deprecated
- func (x *Agent) GetAddresses() string
- func (x *Agent) GetAgentKey() string
- func (x *Agent) GetAliases() string
- func (x *Agent) GetHostname() string
- func (x *Agent) GetId() uint32
- func (x *Agent) GetIp() string
- func (x *Agent) GetLastSeen() string
- func (x *Agent) GetMac() string
- func (x *Agent) GetOs() string
- func (x *Agent) GetOsMajorVersion() string
- func (x *Agent) GetOsMinorVersion() string
- func (x *Agent) GetPlatform() string
- func (x *Agent) GetStatus() Status
- func (x *Agent) GetVersion() string
- func (*Agent) ProtoMessage()
- func (x *Agent) ProtoReflect() protoreflect.Message
- func (x *Agent) Reset()
- func (x *Agent) String() string
- type AgentServiceClient
- type AgentServiceServer
- type Collector
- func (*Collector) Descriptor() ([]byte, []int)deprecated
- func (x *Collector) GetCollectorKey() string
- func (x *Collector) GetGroups() []*CollectorConfigGroup
- func (x *Collector) GetHostname() string
- func (x *Collector) GetId() int32
- func (x *Collector) GetIp() string
- func (x *Collector) GetLastSeen() string
- func (x *Collector) GetModule() CollectorModule
- func (x *Collector) GetStatus() Status
- func (x *Collector) GetVersion() string
- func (*Collector) ProtoMessage()
- func (x *Collector) ProtoReflect() protoreflect.Message
- func (x *Collector) Reset()
- func (x *Collector) String() string
- type CollectorConfigGroup
- func (*CollectorConfigGroup) Descriptor() ([]byte, []int)deprecated
- func (x *CollectorConfigGroup) GetCollectorId() int32
- func (x *CollectorConfigGroup) GetConfigurations() []*CollectorGroupConfigurations
- func (x *CollectorConfigGroup) GetGroupDescription() string
- func (x *CollectorConfigGroup) GetGroupName() string
- func (x *CollectorConfigGroup) GetId() int32
- func (*CollectorConfigGroup) ProtoMessage()
- func (x *CollectorConfigGroup) ProtoReflect() protoreflect.Message
- func (x *CollectorConfigGroup) Reset()
- func (x *CollectorConfigGroup) String() string
- type CollectorGroupConfigurations
- func (*CollectorGroupConfigurations) Descriptor() ([]byte, []int)deprecated
- func (x *CollectorGroupConfigurations) GetConfDataType() string
- func (x *CollectorGroupConfigurations) GetConfDescription() string
- func (x *CollectorGroupConfigurations) GetConfKey() string
- func (x *CollectorGroupConfigurations) GetConfName() string
- func (x *CollectorGroupConfigurations) GetConfRequired() bool
- func (x *CollectorGroupConfigurations) GetConfValue() string
- func (x *CollectorGroupConfigurations) GetGroupId() int32
- func (*CollectorGroupConfigurations) ProtoMessage()
- func (x *CollectorGroupConfigurations) ProtoReflect() protoreflect.Message
- func (x *CollectorGroupConfigurations) Reset()
- func (x *CollectorGroupConfigurations) String() string
- type CollectorModule
- func (CollectorModule) Descriptor() protoreflect.EnumDescriptor
- func (x CollectorModule) Enum() *CollectorModule
- func (CollectorModule) EnumDescriptor() ([]byte, []int)deprecated
- func (x CollectorModule) Number() protoreflect.EnumNumber
- func (x CollectorModule) String() string
- func (CollectorModule) Type() protoreflect.EnumType
- type CollectorServiceClient
- type CollectorServiceServer
- type ConnectorType
- func (ConnectorType) Descriptor() protoreflect.EnumDescriptor
- func (x ConnectorType) Enum() *ConnectorType
- func (ConnectorType) EnumDescriptor() ([]byte, []int)deprecated
- func (x ConnectorType) Number() protoreflect.EnumNumber
- func (x ConnectorType) String() string
- func (ConnectorType) Type() protoreflect.EnumType
- type ListAgentsResponse
- func (*ListAgentsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListAgentsResponse) GetRows() []*Agent
- func (x *ListAgentsResponse) GetTotal() int32
- func (*ListAgentsResponse) ProtoMessage()
- func (x *ListAgentsResponse) ProtoReflect() protoreflect.Message
- func (x *ListAgentsResponse) Reset()
- func (x *ListAgentsResponse) String() string
- type ListCollectorResponse
- func (*ListCollectorResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListCollectorResponse) GetRows() []*Collector
- func (x *ListCollectorResponse) GetTotal() int32
- func (*ListCollectorResponse) ProtoMessage()
- func (x *ListCollectorResponse) ProtoReflect() protoreflect.Message
- func (x *ListCollectorResponse) Reset()
- func (x *ListCollectorResponse) String() string
- type ListRequest
- func (*ListRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListRequest) GetPageNumber() int32
- func (x *ListRequest) GetPageSize() int32
- func (x *ListRequest) GetSearchQuery() string
- func (x *ListRequest) GetSortBy() string
- func (*ListRequest) ProtoMessage()
- func (x *ListRequest) ProtoReflect() protoreflect.Message
- func (x *ListRequest) Reset()
- func (x *ListRequest) String() string
- type Status
- type UnimplementedAgentServiceServer
- type UnimplementedCollectorServiceServer
- type UnsafeAgentServiceServer
- type UnsafeCollectorServiceServer
Constants ¶
This section is empty.
Variables ¶
var ( CollectorModule_name = map[int32]string{ 0: "AS_400", } CollectorModule_value = map[string]int32{ "AS_400": 0, } )
Enum value maps for CollectorModule.
var ( Status_name = map[int32]string{ 0: "ONLINE", 1: "OFFLINE", 2: "UNKNOWN", } Status_value = map[string]int32{ "ONLINE": 0, "OFFLINE": 1, "UNKNOWN": 2, } )
Enum value maps for Status.
var ( ConnectorType_name = map[int32]string{ 0: "AGENT", 1: "COLLECTOR", } ConnectorType_value = map[string]int32{ "AGENT": 0, "COLLECTOR": 1, } )
Enum value maps for ConnectorType.
var AgentService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "agent.AgentService", HandlerType: (*AgentServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListAgents", Handler: _AgentService_ListAgents_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "agent.proto", }
AgentService_ServiceDesc is the grpc.ServiceDesc for AgentService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var CollectorService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "agent.CollectorService", HandlerType: (*CollectorServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListCollector", Handler: _CollectorService_ListCollector_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "collector.proto", }
CollectorService_ServiceDesc is the grpc.ServiceDesc for CollectorService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_agent_proto protoreflect.FileDescriptor
var File_collector_proto protoreflect.FileDescriptor
var File_common_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAgentServiceServer ¶
func RegisterAgentServiceServer(s grpc.ServiceRegistrar, srv AgentServiceServer)
func RegisterCollectorServiceServer ¶
func RegisterCollectorServiceServer(s grpc.ServiceRegistrar, srv CollectorServiceServer)
Types ¶
type Agent ¶
type Agent struct {
Ip string `protobuf:"bytes,1,opt,name=ip,proto3" json:"ip,omitempty"`
Hostname string `protobuf:"bytes,2,opt,name=hostname,proto3" json:"hostname,omitempty"`
Os string `protobuf:"bytes,3,opt,name=os,proto3" json:"os,omitempty"`
Status Status `protobuf:"varint,4,opt,name=status,proto3,enum=agent.Status" json:"status,omitempty"`
Platform string `protobuf:"bytes,5,opt,name=platform,proto3" json:"platform,omitempty"`
Version string `protobuf:"bytes,6,opt,name=version,proto3" json:"version,omitempty"`
AgentKey string `protobuf:"bytes,7,opt,name=agent_key,json=agentKey,proto3" json:"agent_key,omitempty"`
Id uint32 `protobuf:"varint,8,opt,name=id,proto3" json:"id,omitempty"`
LastSeen string `protobuf:"bytes,9,opt,name=last_seen,json=lastSeen,proto3" json:"last_seen,omitempty"`
Mac string `protobuf:"bytes,10,opt,name=mac,proto3" json:"mac,omitempty"`
OsMajorVersion string `protobuf:"bytes,11,opt,name=os_major_version,json=osMajorVersion,proto3" json:"os_major_version,omitempty"`
OsMinorVersion string `protobuf:"bytes,12,opt,name=os_minor_version,json=osMinorVersion,proto3" json:"os_minor_version,omitempty"`
Aliases string `protobuf:"bytes,13,opt,name=aliases,proto3" json:"aliases,omitempty"`
Addresses string `protobuf:"bytes,14,opt,name=addresses,proto3" json:"addresses,omitempty"`
// contains filtered or unexported fields
}
func (*Agent) Descriptor
deprecated
func (*Agent) GetAddresses ¶
func (*Agent) GetAgentKey ¶
func (*Agent) GetAliases ¶
func (*Agent) GetHostname ¶
func (*Agent) GetLastSeen ¶
func (*Agent) GetOsMajorVersion ¶
func (*Agent) GetOsMinorVersion ¶
func (*Agent) GetPlatform ¶
func (*Agent) GetVersion ¶
func (*Agent) ProtoMessage ¶
func (*Agent) ProtoMessage()
func (*Agent) ProtoReflect ¶
func (x *Agent) ProtoReflect() protoreflect.Message
type AgentServiceClient ¶
type AgentServiceClient interface {
ListAgents(ctx context.Context, in *ListRequest, opts ...grpc.CallOption) (*ListAgentsResponse, error)
}
AgentServiceClient is the client API for AgentService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAgentServiceClient ¶
func NewAgentServiceClient(cc grpc.ClientConnInterface) AgentServiceClient
type AgentServiceServer ¶
type AgentServiceServer interface {
ListAgents(context.Context, *ListRequest) (*ListAgentsResponse, error)
// contains filtered or unexported methods
}
AgentServiceServer is the server API for AgentService service. All implementations must embed UnimplementedAgentServiceServer for forward compatibility
type Collector ¶
type Collector struct {
Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Status Status `protobuf:"varint,2,opt,name=status,proto3,enum=agent.Status" json:"status,omitempty"`
CollectorKey string `protobuf:"bytes,3,opt,name=collector_key,json=collectorKey,proto3" json:"collector_key,omitempty"`
Ip string `protobuf:"bytes,4,opt,name=ip,proto3" json:"ip,omitempty"`
Hostname string `protobuf:"bytes,5,opt,name=hostname,proto3" json:"hostname,omitempty"`
Version string `protobuf:"bytes,6,opt,name=version,proto3" json:"version,omitempty"`
Module CollectorModule `protobuf:"varint,7,opt,name=module,proto3,enum=agent.CollectorModule" json:"module,omitempty"`
Groups []*CollectorConfigGroup `protobuf:"bytes,8,rep,name=groups,proto3" json:"groups,omitempty"`
LastSeen string `protobuf:"bytes,9,opt,name=last_seen,json=lastSeen,proto3" json:"last_seen,omitempty"`
// contains filtered or unexported fields
}
func (*Collector) Descriptor
deprecated
func (*Collector) GetCollectorKey ¶
func (*Collector) GetGroups ¶
func (x *Collector) GetGroups() []*CollectorConfigGroup
func (*Collector) GetHostname ¶
func (*Collector) GetLastSeen ¶
func (*Collector) GetModule ¶
func (x *Collector) GetModule() CollectorModule
func (*Collector) GetVersion ¶
func (*Collector) ProtoMessage ¶
func (*Collector) ProtoMessage()
func (*Collector) ProtoReflect ¶
func (x *Collector) ProtoReflect() protoreflect.Message
type CollectorConfigGroup ¶
type CollectorConfigGroup struct {
Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
GroupName string `protobuf:"bytes,3,opt,name=group_name,json=groupName,proto3" json:"group_name,omitempty"`
GroupDescription string `protobuf:"bytes,4,opt,name=group_description,json=groupDescription,proto3" json:"group_description,omitempty"`
Configurations []*CollectorGroupConfigurations `protobuf:"bytes,5,rep,name=configurations,proto3" json:"configurations,omitempty"`
CollectorId int32 `protobuf:"varint,6,opt,name=collector_id,json=collectorId,proto3" json:"collector_id,omitempty"`
// contains filtered or unexported fields
}
func (*CollectorConfigGroup) Descriptor
deprecated
func (*CollectorConfigGroup) Descriptor() ([]byte, []int)
Deprecated: Use CollectorConfigGroup.ProtoReflect.Descriptor instead.
func (*CollectorConfigGroup) GetCollectorId ¶
func (x *CollectorConfigGroup) GetCollectorId() int32
func (*CollectorConfigGroup) GetConfigurations ¶
func (x *CollectorConfigGroup) GetConfigurations() []*CollectorGroupConfigurations
func (*CollectorConfigGroup) GetGroupDescription ¶
func (x *CollectorConfigGroup) GetGroupDescription() string
func (*CollectorConfigGroup) GetGroupName ¶
func (x *CollectorConfigGroup) GetGroupName() string
func (*CollectorConfigGroup) GetId ¶
func (x *CollectorConfigGroup) GetId() int32
func (*CollectorConfigGroup) ProtoMessage ¶
func (*CollectorConfigGroup) ProtoMessage()
func (*CollectorConfigGroup) ProtoReflect ¶
func (x *CollectorConfigGroup) ProtoReflect() protoreflect.Message
func (*CollectorConfigGroup) Reset ¶
func (x *CollectorConfigGroup) Reset()
func (*CollectorConfigGroup) String ¶
func (x *CollectorConfigGroup) String() string
type CollectorGroupConfigurations ¶
type CollectorGroupConfigurations struct {
GroupId int32 `protobuf:"varint,2,opt,name=group_id,json=groupId,proto3" json:"group_id,omitempty"`
ConfKey string `protobuf:"bytes,3,opt,name=conf_key,json=confKey,proto3" json:"conf_key,omitempty"`
ConfValue string `protobuf:"bytes,4,opt,name=conf_value,json=confValue,proto3" json:"conf_value,omitempty"`
ConfName string `protobuf:"bytes,5,opt,name=conf_name,json=confName,proto3" json:"conf_name,omitempty"`
ConfDescription string `protobuf:"bytes,6,opt,name=conf_description,json=confDescription,proto3" json:"conf_description,omitempty"`
ConfDataType string `protobuf:"bytes,7,opt,name=conf_data_type,json=confDataType,proto3" json:"conf_data_type,omitempty"`
ConfRequired bool `protobuf:"varint,8,opt,name=conf_required,json=confRequired,proto3" json:"conf_required,omitempty"`
// contains filtered or unexported fields
}
func (*CollectorGroupConfigurations) Descriptor
deprecated
func (*CollectorGroupConfigurations) Descriptor() ([]byte, []int)
Deprecated: Use CollectorGroupConfigurations.ProtoReflect.Descriptor instead.
func (*CollectorGroupConfigurations) GetConfDataType ¶
func (x *CollectorGroupConfigurations) GetConfDataType() string
func (*CollectorGroupConfigurations) GetConfDescription ¶
func (x *CollectorGroupConfigurations) GetConfDescription() string
func (*CollectorGroupConfigurations) GetConfKey ¶
func (x *CollectorGroupConfigurations) GetConfKey() string
func (*CollectorGroupConfigurations) GetConfName ¶
func (x *CollectorGroupConfigurations) GetConfName() string
func (*CollectorGroupConfigurations) GetConfRequired ¶
func (x *CollectorGroupConfigurations) GetConfRequired() bool
func (*CollectorGroupConfigurations) GetConfValue ¶
func (x *CollectorGroupConfigurations) GetConfValue() string
func (*CollectorGroupConfigurations) GetGroupId ¶
func (x *CollectorGroupConfigurations) GetGroupId() int32
func (*CollectorGroupConfigurations) ProtoMessage ¶
func (*CollectorGroupConfigurations) ProtoMessage()
func (*CollectorGroupConfigurations) ProtoReflect ¶
func (x *CollectorGroupConfigurations) ProtoReflect() protoreflect.Message
func (*CollectorGroupConfigurations) Reset ¶
func (x *CollectorGroupConfigurations) Reset()
func (*CollectorGroupConfigurations) String ¶
func (x *CollectorGroupConfigurations) String() string
type CollectorModule ¶
type CollectorModule int32
const (
CollectorModule_AS_400 CollectorModule = 0
)
func (CollectorModule) Descriptor ¶
func (CollectorModule) Descriptor() protoreflect.EnumDescriptor
func (CollectorModule) Enum ¶
func (x CollectorModule) Enum() *CollectorModule
func (CollectorModule) EnumDescriptor
deprecated
func (CollectorModule) EnumDescriptor() ([]byte, []int)
Deprecated: Use CollectorModule.Descriptor instead.
func (CollectorModule) Number ¶
func (x CollectorModule) Number() protoreflect.EnumNumber
func (CollectorModule) String ¶
func (x CollectorModule) String() string
func (CollectorModule) Type ¶
func (CollectorModule) Type() protoreflect.EnumType
type CollectorServiceClient ¶
type CollectorServiceClient interface {
ListCollector(ctx context.Context, in *ListRequest, opts ...grpc.CallOption) (*ListCollectorResponse, error)
}
CollectorServiceClient is the client API for CollectorService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCollectorServiceClient ¶
func NewCollectorServiceClient(cc grpc.ClientConnInterface) CollectorServiceClient
type CollectorServiceServer ¶
type CollectorServiceServer interface {
ListCollector(context.Context, *ListRequest) (*ListCollectorResponse, error)
// contains filtered or unexported methods
}
CollectorServiceServer is the server API for CollectorService service. All implementations must embed UnimplementedCollectorServiceServer for forward compatibility
type ConnectorType ¶
type ConnectorType int32
const ( ConnectorType_AGENT ConnectorType = 0 ConnectorType_COLLECTOR ConnectorType = 1 )
func (ConnectorType) Descriptor ¶
func (ConnectorType) Descriptor() protoreflect.EnumDescriptor
func (ConnectorType) Enum ¶
func (x ConnectorType) Enum() *ConnectorType
func (ConnectorType) EnumDescriptor
deprecated
func (ConnectorType) EnumDescriptor() ([]byte, []int)
Deprecated: Use ConnectorType.Descriptor instead.
func (ConnectorType) Number ¶
func (x ConnectorType) Number() protoreflect.EnumNumber
func (ConnectorType) String ¶
func (x ConnectorType) String() string
func (ConnectorType) Type ¶
func (ConnectorType) Type() protoreflect.EnumType
type ListAgentsResponse ¶
type ListAgentsResponse struct {
Rows []*Agent `protobuf:"bytes,1,rep,name=rows,proto3" json:"rows,omitempty"`
Total int32 `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
// contains filtered or unexported fields
}
func (*ListAgentsResponse) Descriptor
deprecated
func (*ListAgentsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListAgentsResponse.ProtoReflect.Descriptor instead.
func (*ListAgentsResponse) GetRows ¶
func (x *ListAgentsResponse) GetRows() []*Agent
func (*ListAgentsResponse) GetTotal ¶
func (x *ListAgentsResponse) GetTotal() int32
func (*ListAgentsResponse) ProtoMessage ¶
func (*ListAgentsResponse) ProtoMessage()
func (*ListAgentsResponse) ProtoReflect ¶
func (x *ListAgentsResponse) ProtoReflect() protoreflect.Message
func (*ListAgentsResponse) Reset ¶
func (x *ListAgentsResponse) Reset()
func (*ListAgentsResponse) String ¶
func (x *ListAgentsResponse) String() string
type ListCollectorResponse ¶
type ListCollectorResponse struct {
Rows []*Collector `protobuf:"bytes,1,rep,name=rows,proto3" json:"rows,omitempty"`
Total int32 `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
// contains filtered or unexported fields
}
func (*ListCollectorResponse) Descriptor
deprecated
func (*ListCollectorResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListCollectorResponse.ProtoReflect.Descriptor instead.
func (*ListCollectorResponse) GetRows ¶
func (x *ListCollectorResponse) GetRows() []*Collector
func (*ListCollectorResponse) GetTotal ¶
func (x *ListCollectorResponse) GetTotal() int32
func (*ListCollectorResponse) ProtoMessage ¶
func (*ListCollectorResponse) ProtoMessage()
func (*ListCollectorResponse) ProtoReflect ¶
func (x *ListCollectorResponse) ProtoReflect() protoreflect.Message
func (*ListCollectorResponse) Reset ¶
func (x *ListCollectorResponse) Reset()
func (*ListCollectorResponse) String ¶
func (x *ListCollectorResponse) String() string
type ListRequest ¶
type ListRequest struct {
PageNumber int32 `protobuf:"varint,1,opt,name=page_number,json=pageNumber,proto3" json:"page_number,omitempty"`
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
SearchQuery string `protobuf:"bytes,3,opt,name=search_query,json=searchQuery,proto3" json:"search_query,omitempty"`
SortBy string `protobuf:"bytes,4,opt,name=sort_by,json=sortBy,proto3" json:"sort_by,omitempty"`
// contains filtered or unexported fields
}
func (*ListRequest) Descriptor
deprecated
func (*ListRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListRequest.ProtoReflect.Descriptor instead.
func (*ListRequest) GetPageNumber ¶
func (x *ListRequest) GetPageNumber() int32
func (*ListRequest) GetPageSize ¶
func (x *ListRequest) GetPageSize() int32
func (*ListRequest) GetSearchQuery ¶
func (x *ListRequest) GetSearchQuery() string
func (*ListRequest) GetSortBy ¶
func (x *ListRequest) GetSortBy() string
func (*ListRequest) ProtoMessage ¶
func (*ListRequest) ProtoMessage()
func (*ListRequest) ProtoReflect ¶
func (x *ListRequest) ProtoReflect() protoreflect.Message
func (*ListRequest) Reset ¶
func (x *ListRequest) Reset()
func (*ListRequest) String ¶
func (x *ListRequest) String() string
type Status ¶
type Status int32
func (Status) Descriptor ¶
func (Status) Descriptor() protoreflect.EnumDescriptor
func (Status) EnumDescriptor
deprecated
func (Status) Number ¶
func (x Status) Number() protoreflect.EnumNumber
func (Status) Type ¶
func (Status) Type() protoreflect.EnumType
type UnimplementedAgentServiceServer ¶
type UnimplementedAgentServiceServer struct {
}
UnimplementedAgentServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedAgentServiceServer) ListAgents ¶
func (UnimplementedAgentServiceServer) ListAgents(context.Context, *ListRequest) (*ListAgentsResponse, error)
type UnimplementedCollectorServiceServer ¶
type UnimplementedCollectorServiceServer struct {
}
UnimplementedCollectorServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedCollectorServiceServer) ListCollector ¶
func (UnimplementedCollectorServiceServer) ListCollector(context.Context, *ListRequest) (*ListCollectorResponse, error)
type UnsafeAgentServiceServer ¶
type UnsafeAgentServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAgentServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AgentServiceServer will result in compilation errors.
type UnsafeCollectorServiceServer ¶
type UnsafeCollectorServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCollectorServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CollectorServiceServer will result in compilation errors.